# creates: N.LDA
from gpaw.test import gen
gen('N', write_xml=True)
